@@ -20,7 +20,9 @@ import uuid
 
 from novaclient import api_versions
 from openstack.compute.v2 import flavor as _flavor
-from openstack.compute.v2 import server
+from openstack.compute.v2 import hypervisor as _hypervisor
+from openstack.compute.v2 import server as _server
+from openstack.compute.v2 import server_group as _server_group
 from openstack.compute.v2 import server_interface as _server_interface
 from openstack.compute.v2 import service
 from openstack.compute.v2 import volume_attachment
@@ -339,136 +341,6 @@ class FakeExtension(object):
         return extension
 
 
-class FakeHypervisor(object):
-    """Fake one or more hypervisor."""
-
-    @staticmethod
-    def create_one_hypervisor(attrs=None):
-        """Create a fake hypervisor.
-
-        :param dict attrs:
-            A dictionary with all attributes
-        :return:
-            A FakeResource object, with id, hypervisor_hostname, and so on
-        """
-        attrs = attrs or {}
-
-        # Set default attributes.
-        hypervisor_info = {
-            'id': 'hypervisor-id-' + uuid.uuid4().hex,
-            'hypervisor_hostname': 'hypervisor-hostname-' + uuid.uuid4().hex,
-            'status': 'enabled',
-            'host_ip': '192.168.0.10',
-            'cpu_info': {
-                'aaa': 'aaa',
-            },
-            'free_disk_gb': 50,
-            'hypervisor_version': 2004001,
-            'disk_available_least': 50,
-            'local_gb': 50,
-            'free_ram_mb': 1024,
-            'service': {
-                'host': 'aaa',
-                'disabled_reason': None,
-                'id': 1,
-            },
-            'vcpus_used': 0,
-            'hypervisor_type': 'QEMU',
-            'local_gb_used': 0,
-            'vcpus': 4,
-            'memory_mb_used': 512,
-            'memory_mb': 1024,
-            'current_workload': 0,
-            'state': 'up',
-            'running_vms': 0,
-        }
-
-        # Overwrite default attributes.
-        hypervisor_info.update(attrs)
-
-        hypervisor = fakes.FakeResource(info=copy.deepcopy(hypervisor_info),
-                                        loaded=True)
-        return hypervisor
-
-    @staticmethod
-    def create_hypervisors(attrs=None, count=2):
-        """Create multiple fake hypervisors.
-
-        :param dict attrs:
-            A dictionary with all attributes
-        :param int count:
-            The number of hypervisors to fake
-        :return:
-            A list of FakeResource objects faking the hypervisors
-        """
-        hypervisors = []
-        for i in range(0, count):
-            hypervisors.append(FakeHypervisor.create_one_hypervisor(attrs))
-
-        return hypervisors
-
-
-class FakeHypervisorStats(object):
-    """Fake one or more hypervisor stats."""
-
-    @staticmethod
-    def create_one_hypervisor_stats(attrs=None):
-        """Create a fake hypervisor stats.
-
-        :param dict attrs:
-            A dictionary with all attributes
-        :return:
-            A FakeResource object, with count, current_workload, and so on
-        """
-        attrs = attrs or {}
-
-        # Set default attributes.
-        stats_info = {
-            'count': 2,
-            'current_workload': 0,
-            'disk_available_least': 50,
-            'free_disk_gb': 100,
-            'free_ram_mb': 23000,
-            'local_gb': 100,
-            'local_gb_used': 0,
-            'memory_mb': 23800,
-            'memory_mb_used': 1400,
-            'running_vms': 3,
-            'vcpus': 8,
-            'vcpus_used': 3,
-        }
-
-        # Overwrite default attributes.
-        stats_info.update(attrs)
-
-        # Set default method.
-        hypervisor_stats_method = {'to_dict': stats_info}
-
-        hypervisor_stats = fakes.FakeResource(
-            info=copy.deepcopy(stats_info),
-            methods=copy.deepcopy(hypervisor_stats_method),
-            loaded=True)
-        return hypervisor_stats
-
-    @staticmethod
-    def create_hypervisors_stats(attrs=None, count=2):
-        """Create multiple fake hypervisors stats.
-
-        :param dict attrs:
-            A dictionary with all attributes
-        :param int count:
-            The number of hypervisors to fake
-        :return:
-            A list of FakeResource objects faking the hypervisors
-        """
-        hypervisors = []
-        for i in range(0, count):
-            hypervisors.append(
-                FakeHypervisorStats.create_one_hypervisor_stats(attrs))
-
-        return hypervisors
-
-
 class FakeSecurityGroup(object):
     """Fake one or more security groups."""
 
@@ -672,7 +544,12 @@ class FakeServer(object):
 
         # Overwrite default attributes.
         server_info.update(attrs)
-        return server.Server(**server_info)
+        server = _server.Server(**server_info)
+
+        # Override methods
+        server.trigger_crash_dump = mock.MagicMock()
+
+        return server
 
     @staticmethod
     def create_sdk_servers(attrs=None, methods=None, count=2):
@@ -1290,72 +1167,6 @@ class FakeHost(object):
         return host_info
 
 
-class FakeServerGroup(object):
-    """Fake one server group"""
-
-    @staticmethod
-    def _create_one_server_group(attrs=None):
-        """Create a fake server group
-
-        :param dict attrs:
-            A dictionary with all attributes
-        :return:
-            A FakeResource object, with id and other attributes
-        """
-        if attrs is None:
-            attrs = {}
-
-        # Set default attributes.
-        server_group_info = {
-            'id': 'server-group-id-' + uuid.uuid4().hex,
-            'members': [],
-            'metadata': {},
-            'name': 'server-group-name-' + uuid.uuid4().hex,
-            'project_id': 'server-group-project-id-' + uuid.uuid4().hex,
-            'user_id': 'server-group-user-id-' + uuid.uuid4().hex,
-        }
-
-        # Overwrite default attributes.
-        server_group_info.update(attrs)
-
-        server_group = fakes.FakeResource(
-            info=copy.deepcopy(server_group_info),
-            loaded=True)
-        return server_group
-
-    @staticmethod
-    def create_one_server_group(attrs=None):
-        """Create a fake server group
-
-        :param dict attrs:
-            A dictionary with all attributes
-        :return:
-            A FakeResource object, with id and other attributes
-        """
-        if attrs is None:
-            attrs = {}
-        attrs.setdefault('policies', ['policy1', 'policy2'])
-        return FakeServerGroup._create_one_server_group(attrs)
-
-
-class FakeServerGroupV264(object):
-    """Fake one server group fo API >= 2.64"""
-
-    @staticmethod
-    def create_one_server_group(attrs=None):
-        """Create a fake server group
-
-        :param dict attrs:
-            A dictionary with all attributes
-        :return:
-            A FakeResource object, with id and other attributes
-        """
-        if attrs is None:
-            attrs = {}
-        attrs.setdefault('policy', 'policy1')
-        return FakeServerGroup._create_one_server_group(attrs)
-
-
 class FakeUsage(object):
     """Fake one or more usage."""
 
@@ -1454,7 +1265,7 @@ class FakeQuota(object):
 
     @staticmethod
     def create_one_default_comp_quota(attrs=None):
-        """Crate one quota"""
+        """Create one quota"""
 
         attrs = attrs or {}
 
@@ -1860,6 +1671,98 @@ class FakeVolumeAttachment(object):
         return volume_attachments
 
 
+def create_one_hypervisor(attrs=None):
+    """Create a fake hypervisor.
+
+    :param dict attrs:
+        A dictionary with all attributes
+    :return:
+        A FakeResource object, with id, hypervisor_hostname, and so on
+    """
+    attrs = attrs or {}
+
+    # Set default attributes.
+    hypervisor_info = {
+        'id': 'hypervisor-id-' + uuid.uuid4().hex,
+        'hypervisor_hostname': 'hypervisor-hostname-' + uuid.uuid4().hex,
+        'status': 'enabled',
+        'host_ip': '192.168.0.10',
+        'cpu_info': {
+            'aaa': 'aaa',
+        },
+        'free_disk_gb': 50,
+        'hypervisor_version': 2004001,
+        'disk_available_least': 50,
+        'local_gb': 50,
+        'free_ram_mb': 1024,
+        'service': {
+            'host': 'aaa',
+            'disabled_reason': None,
+            'id': 1,
+        },
+        'vcpus_used': 0,
+        'hypervisor_type': 'QEMU',
+        'local_gb_used': 0,
+        'vcpus': 4,
+        'memory_mb_used': 512,
+        'memory_mb': 1024,
+        'current_workload': 0,
+        'state': 'up',
+        'running_vms': 0,
+    }
+
+    # Overwrite default attributes.
+    hypervisor_info.update(attrs)
+
+    hypervisor = _hypervisor.Hypervisor(**hypervisor_info, loaded=True)
+    return hypervisor
+
+
+def create_hypervisors(attrs=None, count=2):
+    """Create multiple fake hypervisors.
+
+    :param dict attrs:
+        A dictionary with all attributes
+    :param int count:
+        The number of hypervisors to fake
+    :return:
+        A list of FakeResource objects faking the hypervisors
+    """
+    hypervisors = []
+    for i in range(0, count):
+        hypervisors.append(create_one_hypervisor(attrs))
+
+    return hypervisors
+
+
+def create_one_server_group(attrs=None):
+    """Create a fake server group
+
+    :param dict attrs:
+        A dictionary with all attributes
+    :return:
+        A fake ServerGroup object, with id and other attributes
+    """
+    if attrs is None:
+        attrs = {}
+
+    # Set default attributes.
+    server_group_info = {
+        'id': 'server-group-id-' + uuid.uuid4().hex,
+        'member_ids': '',
+        'metadata': {},
+        'name': 'server-group-name-' + uuid.uuid4().hex,
+        'project_id': 'server-group-project-id-' + uuid.uuid4().hex,
+        'user_id': 'server-group-user-id-' + uuid.uuid4().hex,
+    }
+
+    # Overwrite default attributes.
+    server_group_info.update(attrs)
+
+    server_group = _server_group.ServerGroup(**server_group_info)
+    return server_group
+
+
 def create_one_server_interface(attrs=None):
     """Create a fake SDK ServerInterface.
 
