@@ -71,10 +71,10 @@ def _check_size_arg(args):
     volume is not specified.
     """
 
-    if ((args.snapshot or args.source)
+    if ((args.snapshot or args.source or args.backup)
             is None and args.size is None):
-        msg = _("--size is a required option if snapshot "
-                "or source volume is not specified.")
+        msg = _("--size is a required option if snapshot, backup "
+                "or source volume are not specified.")
         raise exceptions.CommandError(msg)
 
 
@@ -82,18 +82,19 @@ class CreateVolume(command.ShowOne):
     _description = _("Create new volume")
 
     def get_parser(self, prog_name):
-        parser = super(CreateVolume, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             "name",
             metavar="<name>",
+            nargs="?",
             help=_("Volume name"),
         )
         parser.add_argument(
             "--size",
             metavar="<size>",
             type=int,
-            help=_("Volume size in GB (Required unless --snapshot or "
-                   "--source is specified)"),
+            help=_("Volume size in GB (required unless --snapshot, "
+                   "--source or --backup is specified)"),
         )
         parser.add_argument(
             "--type",
@@ -116,6 +117,12 @@ class CreateVolume(command.ShowOne):
             metavar="<volume>",
             help=_("Volume to clone (name or ID)"),
         )
+        source_group.add_argument(
+            "--backup",
+            metavar="<backup>",
+            help=_("Restore backup to a volume (name or ID) "
+                   "(supported by --os-volume-api-version 3.47 or later)"),
+        )
         source_group.add_argument(
             "--source-replicated",
             metavar="<replicated-volume>",
@@ -176,14 +183,28 @@ class CreateVolume(command.ShowOne):
 
     def take_action(self, parsed_args):
         _check_size_arg(parsed_args)
+        # size is validated in the above call to
+        # _check_size_arg where we check that size
+        # should be passed if we are not creating a
+        # volume from snapshot, backup or source volume
+        size = parsed_args.size
+
         volume_client = self.app.client_manager.volume
         image_client = self.app.client_manager.image
 
+        if parsed_args.backup and not (
+                volume_client.api_version.matches('3.47')):
+            msg = _("--os-volume-api-version 3.47 or greater is required "
+                    "to create a volume from backup.")
+            raise exceptions.CommandError(msg)
+
         source_volume = None
         if parsed_args.source:
-            source_volume = utils.find_resource(
+            source_volume_obj = utils.find_resource(
                 volume_client.volumes,
-                parsed_args.source).id
+                parsed_args.source)
+            source_volume = source_volume_obj.id
+            size = max(size or 0, source_volume_obj.size)
 
         consistency_group = None
         if parsed_args.consistency_group:
@@ -196,8 +217,6 @@ class CreateVolume(command.ShowOne):
             image = image_client.find_image(parsed_args.image,
                                             ignore_missing=False).id
 
-        size = parsed_args.size
-
         snapshot = None
         if parsed_args.snapshot:
             snapshot_obj = utils.find_resource(
@@ -212,6 +231,15 @@ class CreateVolume(command.ShowOne):
             # snapshot size.
             size = max(size or 0, snapshot_obj.size)
 
+        backup = None
+        if parsed_args.backup:
+            backup_obj = utils.find_resource(
+                volume_client.backups,
+                parsed_args.backup)
+            backup = backup_obj.id
+            # As above
+            size = max(size or 0, backup_obj.size)
+
         volume = volume_client.volumes.create(
             size=size,
             snapshot_id=snapshot,
@@ -224,6 +252,7 @@ class CreateVolume(command.ShowOne):
             source_volid=source_volume,
             consistencygroup_id=consistency_group,
             scheduler_hints=parsed_args.hint,
+            backup_id=backup,
         )
 
         if parsed_args.bootable or parsed_args.non_bootable:
@@ -361,7 +390,6 @@ class ListVolume(command.Lister):
     def take_action(self, parsed_args):
 
         volume_client = self.app.client_manager.volume
-        compute_client = self.app.client_manager.compute
         identity_client = self.app.client_manager.identity
 
         if parsed_args.long:
@@ -393,6 +421,7 @@ class ListVolume(command.Lister):
         # Cache the server list
         server_cache = {}
         try:
+            compute_client = self.app.client_manager.compute
             for s in compute_client.servers.list():
                 server_cache[s.id] = s
         except Exception:
